if (app.documents.length > 0) {
    var doc = app.activeDocument;
    app.preferences.rulerUnits = RulerUnits.Inches; // Set ruler units to inches

    var originalSelection = doc.selection; // Store the original selection

    if (originalSelection.length > 0) {
        // Sort the selection by the leftmost X-coordinate
        originalSelection.sort(function (a, b) {
            return a.geometricBounds[0] - b.geometricBounds[0];
        });

        // Get the active artboard bounds in inches
        var artboard = doc.artboards[doc.artboards.getActiveArtboardIndex()];
        var artboardBounds = artboard.artboardRect;
        var artboardWidth = (artboardBounds[2] - artboardBounds[0]) / 72; // Convert width to inches

        // Calculate total width of all shapes
        var totalShapeWidth = 0;
        for (var i = 0; i < originalSelection.length; i++) {
            var itemBounds = originalSelection[i].geometricBounds;
            var itemWidth = Math.abs(itemBounds[2] - itemBounds[0]); // Width of each shape
            totalShapeWidth += itemWidth / 72; // Convert to inches and add to total
        }

        // Calculate the spacing between shapes
        var numberOfSpaces = originalSelection.length + 1;
        var totalSpacing = artboardWidth - totalShapeWidth; // Remaining space after accounting for shapes
        var spacing = totalSpacing / numberOfSpaces;

        // Distribute shapes with calculated spacing
        var currentX = artboardBounds[0] / 72 + spacing; // Start at the left edge, factoring in the first gap
        for (var j = 0; j < originalSelection.length; j++) {
            var item = originalSelection[j];
            var itemBounds = item.geometricBounds;
            var itemWidth = Math.abs(itemBounds[2] - itemBounds[0]) / 72; // Width in inches
            var itemCenterX = currentX + itemWidth / 2; // Center of the current item
            var deltaX = itemCenterX - (itemBounds[0] / 72 + itemWidth / 2); // Calculate shift
            item.translate(deltaX * 72, 0); // Move item (convert inches back to points)
            currentX += itemWidth + spacing; // Move to the next position
        }
    }
}