if (app.documents.length > 0) {
    var doc = app.activeDocument;
    app.preferences.rulerUnits = RulerUnits.Inches; // Set ruler units to inches

    var originalSelection = doc.selection; // Store the original selection

    if (originalSelection.length > 0) {
        // Get the active artboard bounds in inches
        var artboard = doc.artboards[doc.artboards.getActiveArtboardIndex()];
        var artboardBounds = artboard.artboardRect;
        var artboardHeight = (artboardBounds[1] - artboardBounds[3]) / 72; // Convert height to inches

        // Calculate total height of all shapes
        var totalShapeHeight = 0;
        for (var i = 0; i < originalSelection.length; i++) {
            var itemBounds = originalSelection[i].geometricBounds;
            var itemHeight = Math.abs(itemBounds[1] - itemBounds[3]); // Height of each shape
            totalShapeHeight += itemHeight / 72; // Convert to inches and add to total
        }

        // Calculate the spacing between shapes
        var numberOfSpaces = originalSelection.length + 1;
        var totalSpacing = artboardHeight - totalShapeHeight; // Remaining space after accounting for shapes
        var spacing = totalSpacing / numberOfSpaces;

        // Distribute shapes with calculated spacing
        var currentY = artboardBounds[1] / 72 - spacing; // Start at the top edge, factoring in the first gap
        for (var j = 0; j < originalSelection.length; j++) {
            var item = originalSelection[j];
            var itemBounds = item.geometricBounds;
            var itemHeight = Math.abs(itemBounds[1] - itemBounds[3]) / 72; // Height in inches
            var itemCenterY = currentY - itemHeight / 2; // Center of the current item
            var deltaY = itemCenterY - (itemBounds[1] / 72 - itemHeight / 2); // Calculate shift
            item.translate(0, deltaY * 72); // Move item (convert inches back to points)
            currentY -= itemHeight + spacing; // Move to the next position
        }
    }
}
